@@ -18,6 +18,7 @@ from colorama import init, Fore, Style
 
 from jutge import util
 from . import compilers
+from . import checkers
 
 # ----------------------------------------------------------------------------
 # Global variables
@@ -223,6 +224,7 @@ def verify_program(program, correct_extension='', iterations=1):
     for solution, compiler in sorted(available_list, key=lambda tup: tup[0].lower()):
         print("Verifying " + solution + "...")
         ext = os.path.splitext(solution)[-1]
+        pe = False
         for test in tests:
             tst = os.path.splitext(test)[0]
             time = compiler.execute(tst, False, iterations)
@@ -230,19 +232,22 @@ def verify_program(program, correct_extension='', iterations=1):
                 os.rename("output.png", tst + ext + ".out")
             outsize = os.path.getsize(tst + ext + ".out")
 
-            r = subprocess.call(["cmp", tst + ext + ".out", tst + ".cor"])
-            if r:
-                has_failed = True
-                msg = "WA"
-            else:
-                msg = "OK"
+            r = checkers.standard(tst + ext + ".out", tst + ".cor", pe=True)
+            if r == 'AC':
                 util.del_file(tst + ext + ".out")
-            print((Fore.GREEN if msg == 'OK' else Fore.RED) +
+            if r == 'PE':
+                pe = True
+            print((Fore.GREEN if r == 'AC' else Fore.YELLOW if r == 'PE' else Fore.RED) +
                   "%s.inp:\t\t%s\ntime: %f\t\tsize: %s" %
-                  (tst, msg, time, util.convert_bytes(outsize)) + Style.RESET_ALL)
+                  (tst, r, time, util.convert_bytes(outsize)) + Style.RESET_ALL)
             if outsize > 2000000 and not os.path.isfile(tst + ext + ".ops"):
                 print(Fore.YELLOW + 'Warning: The output file is bigger than 2MB, you may need a .ops file for this test case.')
+
         print()
+        handler = util.read_yml("handler.yml")
+        if pe and ('checker' not in handler or handler['checker'] != 'loosy'):
+            print(Fore.YELLOW + 'Warning: Some outputs were slightly different from the correct files. Please consider using the loosy checker.\n')
+
 
     if has_failed:
         print(Fore.RED + "Some solutions are not correct! Please check them and try again." + Style.RESET_ALL)
